#
# spec file for package python-tomli
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-tomli
Version:        2.1.0
Release:        1.2
Summary:        A lil' TOML parser
License:        MIT
URL:            https://github.com/hukkin/tomli
# prefer github archive over pypi sdist for pacakged tests
Source:         https://github.com/hukkin/tomli/archive/refs/tags/%{version}.tar.gz#/tomli-%{version}.tar.gz
BuildRequires:  %{python_module flit-core}
BuildRequires:  %{python_module pip}
# Avoid build cycles
# https://flit.readthedocs.io/en/latest/bootstrap.html
#!BuildIgnore:  python3-tomli
#!BuildIgnore:  python36-tomli
#!BuildIgnore:  python38-tomli
#!BuildIgnore:  python39-tomli
#!BuildIgnore:  python310-tomli
#!BuildIgnore:  ca-certificates
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildArch:      noarch
%python_subpackages

%description
Tomli is a Python library for parsing TOML

%prep
%autosetup -p1 -n tomli-%{version}

%build
# flit_core requires tomli
export PYTHONPATH=$PWD/src
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pyunittest -v

%files %{python_files}
%license LICENSE
%doc README.md
%{python_sitelib}/tomli
%{python_sitelib}/tomli-%{version}.dist-info

%changelog
* Wed Nov 20 2024 Dirk Müller <dmueller@suse.com>
- update to 2.1.0:
  * Instantiating `TOMLDecodeError` with free-form arguments.
  * `msg`, `doc` and `pos` arguments should be given.
  * Added `msg`, `doc`, `pos`, `lineno` and `colno` attributes to
    `TOMLDecodeError`
* Fri Oct 11 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 2.0.2
  * Removed
  - Python 3.7 support
  * Improved
  - Make `loads` raise `TypeError` not `AttributeError` on bad
    input types that do not have the `replace` attribute.
    Improve error message when `bytes` is received.
  * Type annotations
  - Type annotate `load` input as `typing.IO[bytes]`
    (previously `typing.BinaryIO`).
* Mon Aug 12 2024 Matej Cepl <mcepl@cepl.eu>
- Make testing more verbose
* Fri Apr 21 2023 Dirk Müller <dmueller@suse.com>
- add sle15_python_module_pythons (jsc#PED-68)
* Thu Apr 13 2023 Matej Cepl <mcepl@suse.com>
- Make calling of %%{sle15modernpython} optional.
* Fri Feb 25 2022 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to 2.0.1:
  * More uniform error messages
  * Raise a friendly TypeError for wrong file mode
  * Allow parse_float to return objects having the append attr
  * Eagerly raise an error if parse_float returns an illegal type
  * Tests ported to unittest
- Merge base and -test package, there is no extra dependency any
  more, tests just need the python interpreter
* Thu Jan 20 2022 Matej Cepl <mcepl@suse.com>
- Upgrade to 2.0.0:
  - Removed Python 3.6 support
  - Support for text file objects as load input. Use binary file
    objects instead.
  - First argument of load and loads can no longer be passed by
    keyword.
  - Allow lower case "t" and "z" in datetimes
  - Raise an error when dotted keys define values outside the
    "current table". Technically speaking TOML v1.0.0 does allow
    such assignments but that isn't intended by specification
    writers, and will change in a future specification version
    (see the pull request).
  - Illegal characters in error messages were surrounded by two
    pairs of quotation marks
  - TOMLDecodeError.__module__ is now the public import path
    (tomli) instead of private import path (tomli._parser)
  - Eliminated an import cycle when typing.TYPE_CHECKING is
    True. This allows sphinx-autodoc-typehints to resolve type
    annotations.
* Fri Oct 15 2021 Ben Greiner <code@bnavigator.de>
- Yet another dependency cycle to break: tomli - flit_core - tomli
  https://flit.readthedocs.io/en/latest/bootstrap.html
* Fri Oct 15 2021 Dominique Leuenberger <dimstar@opensuse.org>
- BuildIgnore ca-certificates: python-pip brings it in for regular
  operation, but as we do not ever do https:// connections during a
  build we do not depend on certificates. Allows us to break up a
  build cycle.
* Wed Oct 13 2021 Ben Greiner <code@bnavigator.de>
- Split build and tests in _multibuild in order to avoid depcycle
* Sun Oct  3 2021 Ben Greiner <code@bnavigator.de>
- initial specfile for version 1.2.1
- required by setuptools_scm
